@@ -5,7 +5,7 @@
 #
 # Project   : SAPIADAPTER
 # Author(s) : Zafar Iqbal < zaf@sparc.space >
-# Copyright : (C) 2021 SPARC PC < https://sparc.space/ >
+# Copyright : (C) 2022 SPARC PC < https://sparc.space/ >
 #
 # All rights reserved. No warranty, explicit or implicit, provided.
 # SPARC PC is and remains the owner of all titles, rights
@@ -39,14 +39,11 @@ def setup( config_user = None ) :
     flag = init( config_user ) 
 
     if not flag :
-        s_log.write( "Not setup ready!" )
-        return( falg )
+        s_log.write( "False init!" )
+        return( flag )
 
-    handle_key_fromcontainer( )
-    unpack_key( )
-    handle_sslverify_fornumericip( )
-    handle_key_public( )
-    checkup_workspacedir( )
+
+    preprocess( ) 
 
     ready = True
 
@@ -55,6 +52,15 @@ def setup( config_user = None ) :
 
     return( True )
 
+
+def preprocess( ) :
+    handle_key_fromcontainer( )
+    unpack_key( )
+    handle_sslverify_fornumericip( )
+    handle_key_public( )
+    checkup_workspacedir( )
+
+
 def get_key( config_key , default_val = None ) :
 
     #    config[ "/config/init/path" ] = config_path
@@ -106,7 +112,7 @@ def handle_key_fromcontainer( ) :
 
 def handle_key_public( ) :
 
-    if( get_key( "endpoint/url"  ) ) : return
+    if( get_key( "endpoint/url"  ) != False ) : return
 
     set_key_alt( "endpoint/url" , "https://sapiomnibus-public.sparc.space" )
 
@@ -133,8 +139,8 @@ def handle_sslverify_fornumericip( ) :
     ########################################################
 
     host = get_key( "endpoint/host" )
-    s_log.write(host)
-    if(not host): return
+    #s_log.write(host)
+    if( not host ) : return
 
     if host.endswith(".test"):
         set_key_alt( "endpoint/sslverify" , "no" )
@@ -142,26 +148,53 @@ def handle_sslverify_fornumericip( ) :
 
 def unpack_key( ) :
 
+    # TOKEN|IP:PORT|HOST
+    # DEF|DEF|DEF
+
     endpoint_key = get_key( "endpoint/key" )
 
+    #s_log.write(endpoint_key)
+
     if( not endpoint_key ) :
         return
 
+    ########################################################
 
-    parts = endpoint_key.split( "|" )
+    key_parts = endpoint_key.split( "|" )
+    key_parts_total = len( key_parts )
+    # s_log.write( key_parts_total )
 
-    endpoint_url_token = endpoint_key
+    ########################################################
 
-    # FIXME TODO do not use ALT config
-    # FIXME TODO set blank or remove endpoint/host if not given
-    if( len( parts ) == 2 ) :
-        endpoint_url_token = parts[ 0 ]
-        set_key_alt( "endpoint/host" , parts[ 1 ] )
+    if( key_parts_total != 3 ) :
+        s_log.write( "key_parts_total != 3 " )
+        return
 
-    url = endpoint_url_token[ 0:-67 ]
-    token = endpoint_url_token[ -67: ]
+    ########################################################
 
-    if( url[ 0:4 ] != "http" ) : url = "https://" + url
+
+    if( ( key_parts[ 0 ] != "*" ) and ( len(key_parts[ 0 ]) == 67) ) :
+        #set_key_alt( "endpoint/token" , key_parts[ 0 ] )
+        set_key( "endpoint/token" , key_parts[ 0 ] )
+
+
+    ########################################################
+
+    if( ( key_parts[ 1 ] != "*" ) ) :
+        url = key_parts[ 1 ]
+        if( url[ 0:4 ] != "http" ) : url = "https://" + url
+        #set_key_alt( "endpoint/url" , url )
+        set_key( "endpoint/url" , url )
+
+    ########################################################
+
+    if( ( key_parts[ 2 ] != "*" ) ) :
+        #set_key_alt( "endpoint/host" , key_parts[ 2 ] )
+        set_key( "endpoint/host" , key_parts[ 2 ] )
+
+    ########################################################
+
+    # FIXME TODO do not use ALT config ?
 
     #s_log.write(url)
     #purl = s_util.url_parse(url)
@@ -169,8 +202,6 @@ def unpack_key( ) :
     #s_log.write(purl.hostname)
     #s_log.write(purl.port)
 
-    set_key_alt( "endpoint/url" , url )
-    set_key_alt( "endpoint/token" , token )
 
     return
 
@@ -312,6 +343,7 @@ def init( config_user = None ) :
     if( config_user ) :
         config.update( config_user )
         config[ "/config/init/from" ] = "config_user"
+        preprocess()
         return( True ) 
 
     ################################################################
@@ -322,6 +354,7 @@ def init( config_user = None ) :
         if( init_fromfile( os.environ[ "SAPIADAPTER_CONFIGURATION" ] ) ) :
             s_log.write( "Loaded SAPIADAPTER_CONFIGURATION " + os.environ[ "SAPIADAPTER_CONFIGURATION" ] )
             config[ "/config/init/from" ] = "environ_file"
+            preprocess()
             return( True )
         else :
             return( False )
@@ -338,6 +371,7 @@ def init( config_user = None ) :
         if( init_fromfile( config_default_filename ) ) :
             s_log.write( "Loaded " + config_default_filename )
             config[ "/config/init/from" ] = "cwd_file"
+            preprocess()
             return( True )
         return( False )
 
@@ -351,6 +385,7 @@ def init( config_user = None ) :
         if( init_fromfile( testpath + config_default_filename ) ) :
             s_log.write( "Loaded " + testpath + config_default_filename )
             config[ "/config/init/from" ] = "testsdata_file"
+            preprocess()
             return( True )
         return( False )
 
@@ -372,4 +407,9 @@ def init( config_user = None ) :
 
     #s_log.write( "Not found " + os.getcwd( ) + "/" + testpath + config_default_filename )
 
+
+    s_log.write( "No loading from config file" )
+
+    preprocess()
+
     return( True )
