@@ -5,7 +5,7 @@
 #
 # Project   : SAPIADAPTER
 # Author(s) : Zafar Iqbal < zaf@sparc.space >
-# Copyright : (C) 2021 SPARC PC < https://sparc.space/ >
+# Copyright : (C) 2022 SPARC PC < https://sparc.space/ >
 #
 # All rights reserved. No warranty, explicit or implicit, provided.
 # SPARC PC is and remains the owner of all titles, rights
@@ -17,6 +17,7 @@ import os
 import sys
 import json
 import time
+import platform
 #import datetime
 import hashlib
 import sqlite3
@@ -102,8 +103,14 @@ def init_data( ) :
     #sys_create( "sys_platform" , sys.platform )
     #sys_create( "sys_version" , sys.version )
     sys_create( "traceid" , s_log.get_traceid( ) )
-    #sys_create( "time_isoformat" , s_util.time_getisoformat( ) )
+    sys_create( "time_isoformat" , s_util.time_getisoformat( ) )
     sys_create( "tcreate" , time.time( ) )
+    sys_create( "platform_uname" , platform.uname( ) )
+    sys_create( "python_version" , platform.python_version( ) )
+
+    sys_create( "config_dbpassthru" , s_config.get_key("db/passthru") )
+
+    s_log.write(sys_read("time_isoformat"))
 
 def fdelete( ) :
 
