@@ -5,7 +5,7 @@
 #
 # Project   : SAPIADAPTER
 # Author(s) : Zafar Iqbal < zaf@sparc.space >
-# Copyright : (C) 2021 SPARC PC < https://sparc.space/ >
+# Copyright : (C) 2022 SPARC PC < https://sparc.space/ >
 #
 # All rights reserved. No warranty, explicit or implicit, provided.
 # SPARC PC is and remains the owner of all titles, rights
@@ -86,12 +86,12 @@ def time_getisoformat( ) :
 
 #>>> now = datetime.now()
 #>>> now
-#datetime.datetime(2021, 11, 29, 11, 55, 27, 172480)
+#datetime.datetime(2010, 11, 29, 11, 55, 27, 172480)
 #>>> now.tzname()
 #>>> from dateutil import tz
 #>>> now = datetime.now(tz=tz.tzlocal())
 #>>> now
-#datetime.datetime(2021, 11, 29, 11, 56, 21, 316679, tzinfo=tzlocal())
+#datetime.datetime(2010, 11, 29, 11, 56, 21, 316679, tzinfo=tzlocal())
 #>>> now.tzname()
 
 def pickle_load( datakey , fromtmp = False ) :
@@ -151,6 +151,9 @@ def uhash( prefix = "" ) :
 def hash( str , prefix = "" ) :
     return( prefix + hashlib.sha256( str ).hexdigest( ) )
 
+def hash_file_md5( fp ) :
+    return( hashlib.md5( open( fp , "rb" ).read( ) ).hexdigest( ) )
+
 def base64_decode( str ) :
     m = base64.b64decode( str ).decode( "utf-8" )
     return( m )
@@ -389,6 +392,10 @@ def container_appenvstatic_get( ) :
 def datetime_iso( ) :
     return( datetime.now( datetime.now( ).astimezone( ).tzinfo ).isoformat( ) )
 
+def time_now( ) :
+    return(time.time())
+def datetime_utcnow( ) :
+    return(datetime.utcnow( ) )
 
 def url_parse( u ) :
     return(urllib.parse.urlparse(u))
@@ -414,5 +421,21 @@ def datetime_inrange_db( dbdt1 , dbdt2 , td) :
 
     dtdiff=d2-d1
     dtdiff_seconds=int(dtdiff.total_seconds())
-    return(dtdiff_seconds<=td)
+    return( dtdiff_seconds <= td )
+
+################
+
+# Return file getcontents given filename and parent script __FILE__
+def file_getcontent( fn , scp ) :
+
+    fd = os.path.dirname( os.path.realpath( scp ) )
+
+    #s_log.write(fn +","+scp)
+
+    with open( fd + "/" + fn , mode = "rb" ) as tfile : 
+        contents = tfile.read( ).decode( )
+
+    return( contents )
+
+
 
